@@ -8,7 +8,7 @@
 ##############################################################################
 
 package AtExit;
-$AtExit::VERSION = '2.02';
+$AtExit::VERSION = '2.03';
 # ABSTRACT: perform exit processing for a program or object
 
 require 5.002;
@@ -257,6 +257,10 @@ is destroyed.
 L<B::Hooks::EndOfScope> will execute your code after the scope finishes
 I<compiling>.
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/AtExit>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 1996 by Brad Appleton.
